/*
 * file CcAttributeType.java
 *
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM
 *
 * com.ibm.rational.wvcm.stp.cc.CcAttributeType
 * 
 * (C) Copyright IBM Corporation 2004, 2008.  All Rights Reserved. 
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or  
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
 */

package com.ibm.rational.wvcm.stp.cc;

import com.ibm.rational.wvcm.stp.cc.CcTypeBase.Scope;
import com.ibm.rational.wvcm.stpex.StpExEnumeration;
import com.ibm.rational.wvcm.stpex.StpExEnumerationBase;

/**
 * <p>A proxy for a ClearCase attribute type.
 * </p>
 * <p>The ClearCase attribute mechanism lets you associate arbitrary
 * name/value pairs with particular ClearCase versions or elements.
 * </p>
 * <p>Attributes are typically used to customize and extend standard
 * ClearCase functionality.  For example, to notify various people in your group
 * when particular files are modified, you could store those peoples' email
 * addresses in an "EmailList" attribute associated with each element of interest.
 * Then associate a checkin "post-op" trigger with those
 * elements that reads the attribute value and sends the notice.
 * </p>
 * <p>You can also use the cleartool "find" command to find elements and
 * versions based on their attributes.
 * </p>
 * <p>For more attribute information, see the ClearCase "Guide to Managing Software Projects"
 * manual, and the cleartool man pages "mkattype" and "find".
 * </p>
 */
public interface CcAttributeType extends CcTypeBase
{
    /**
     * Value type of a ClearCase attribute type.
     * The value type determines helps constrain the legal values and format of an
     * attribute instance.  
     */
    enum ValueType implements StpExEnumeration 
    {
        /** Value is an integer. */
        INTEGER,

        /** Value is floating-point. */
        REAL,
        
        /** Value is a string. */
        STRING,
        
        /** Value represents a time. */
        TIME,
        
        /** Value is an opaque arbitrary byte sequences. */
        OPAQUE;
    }

}
